# Readme

[![pypi](https://img.shields.io/pypi/v/mnamer.svg?style=for-the-badge)](https://pypi.python.org/pypi/mnamer) [![travis_ci](https://img.shields.io/travis/jkwill87/mnamer/master.svg?style=for-the-badge)](https://travis-ci.org/jkwill87/mnamer) [![coverage](https://img.shields.io/codecov/c/github/jkwill87/mnamer/master.svg?style=for-the-badge)](https://codecov.io/gh/jkwill87/mnamer) [![licence](https://img.shields.io/github/license/jkwill87/mnamer.svg?style=for-the-badge)](https://en.wikipedia.org/wiki/MIT_License) [![style black](https://img.shields.io/badge/Style-Black-black.svg?style=for-the-badge)](https://github.com/ambv/black)

![](https://github.com/jkwill87/mnamer/raw/master/assets/logo.png)

## mnamer

mnamer \(**m**edia re**namer**\) is an intelligent and highly configurable media organization utility. It parses media filenames for metadata, searches the web to fill in the blanks, and then renames and moves them.

Currently it has integration support with [TVDb](https://thetvdb.com) and [TvMaze](https://www.tvmaze.com) for television episodes and [TMDb](https://www.themoviedb.org/) and [OMDb](https://www.omdbapi.com) for movies.

![](https://github.com/jkwill87/mnamer/raw/master/assets/screenshot.png)

### Installation

`$ pip3 install mnamer`

### Usage

`$ mnamer target [targets ...] [preferences] [directives]`

### Documentation

See mnamer's [GitBook page](https://jkwill87.gitbook.io/mnamer) for the full documentation.
